@@ -1,5 +1,4 @@
-__version__ = "0.5.1.post1"
+__version__ = "0.5.2"
 
 from .experiments import experiment
-from .oag import oagbert
 from .pipelines import pipeline
