@@ -125,6 +125,9 @@ SUPPORTED_DATASETS = {
     "squirrel": "cogdl.datasets.geom_data.SquirrelDataset",
     "texas": "cogdl.datasets.geom_data.TexasDataset",
     "wisconsin": "cogdl.datasets.geom_data.WisconsinDataset",
+    "cora_geom": "cogdl.datasets.geom_data.CoraGeomDataset",
+    "citeseer_geom": "cogdl.datasets.geom_data.CiteSeerGeomDataset",
+    "pubmed_geom": "cogdl.datasets.geom_data.PubMedGeomDataset",
     "blogcatalog": "cogdl.datasets.matlab_matrix.BlogcatalogDataset",
     "flickr-ne": "cogdl.datasets.matlab_matrix.FlickrDataset",
     "dblp-ne": "cogdl.datasets.matlab_matrix.DblpNEDataset",
