@@ -1,12 +1,13 @@
 import hashlib
+
+import torch
 from joblib import Parallel, delayed
 import networkx as nx
 import numpy as np
 from gensim.models.word2vec import Word2Vec
-from .. import BaseModel, register_model
+from .. import BaseModel
 
 
-@register_model("dgk")
 class DeepGraphKernel(BaseModel):
     r"""The Hin2vec model from the `"Deep Graph Kernels"
     <https://dl.acm.org/citation.cfm?id=2783417&CFID=763322570&CFTOKEN=93890155>`_ paper.
@@ -17,7 +18,7 @@ class DeepGraphKernel(BaseModel):
         window (int) : The actual context size which is considered in language model.
         sampling_rate (float) : Parameter in word2vec.
         iteration (int) : The number of iteration in WL method.
-        epoch (int) : The number of training iteration.
+        epochs (int) : The number of training iteration.
         alpha (float) : The learning rate of word2vec.
     """
 
@@ -28,18 +29,19 @@ class DeepGraphKernel(BaseModel):
         parser.add_argument("--min-count", type=int, default=1)
         parser.add_argument("--sampling", type=float, default=0.0001)
         parser.add_argument("--iteration", type=int, default=2)
-        parser.add_argument("--epoch", type=int, default=20)
+        parser.add_argument("--epochs", type=int, default=20)
         parser.add_argument("--alpha", type=float, default=0.01)
 
     @classmethod
     def build_model_from_args(cls, args):
         return cls(
-            args.hidden_size, args.min_count, args.window_size, args.sampling, args.iteration, args.epoch, args.alpha
+            args.hidden_size, args.min_count, args.window_size, args.sampling, args.iteration, args.epochs, args.alpha
         )
 
     @staticmethod
     def feature_extractor(data, rounds, name):
-        graph = nx.from_edgelist(np.array(data.edge_index.T.cpu(), dtype=int))
+        edge_index = torch.stack(data.edge_index)
+        graph = nx.from_edgelist(np.array(edge_index.T.cpu(), dtype=int))
         if data.x is not None:
             feature = {int(key): str(val.argmax(axis=0)) for key, val in enumerate(np.array(data.x.cpu()))}
         else:
@@ -65,7 +67,7 @@ class DeepGraphKernel(BaseModel):
             features = new_feats
         return wl_features
 
-    def __init__(self, hidden_dim, min_count, window_size, sampling_rate, rounds, epoch, alpha, n_workers=4):
+    def __init__(self, hidden_dim, min_count, window_size, sampling_rate, rounds, epochs, alpha, n_workers=4):
         super(DeepGraphKernel, self).__init__()
         self.hidden_dim = hidden_dim
         self.min_count = min_count
@@ -75,7 +77,7 @@ class DeepGraphKernel(BaseModel):
         self.rounds = rounds
         self.model = None
         self.gl_collections = None
-        self.epoch = epoch
+        self.epochs = epochs
         self.alpha = alpha
 
     def forward(self, graphs, **kwargs):
@@ -91,7 +93,7 @@ class DeepGraphKernel(BaseModel):
             min_count=self.min_count,
             sample=self.sampling_rate,
             workers=self.n_workers,
-            iter=self.epoch,
+            iter=self.epochs,
             alpha=self.alpha,
         )
         vectors = np.asarray([model.wv[str(node)] for node in model.wv.index2word])
