@@ -9,7 +9,7 @@ import torch.nn as nn
 import torch.nn.functional as F
 from tqdm import tqdm
 
-from .. import BaseModel, register_model
+from .. import BaseModel
 
 
 class DNGR_layer(nn.Module):
@@ -38,7 +38,6 @@ class DNGR_layer(nn.Module):
         return encoded, decoded
 
 
-@register_model("dngr")
 class DNGR(BaseModel):
     r"""The DNGR model from the `"Deep Neural Networks for Learning Graph Representations"
     <https://www.aaai.org/ocs/index.php/AAAI/AAAI16/paper/download/12423/11715>`_ paper
@@ -49,7 +48,7 @@ class DNGR(BaseModel):
         noise (float) : Denoise rate of DAE.
         alpha (float) : Parameter in DNGR.
         step (int) : The max step in random surfing.
-        max_epoch (int) : The max epoches in training step.
+        epochs (int) : The max epoches in training step.
         lr (float) : Learning rate in DNGR.
     """
 
@@ -68,18 +67,19 @@ class DNGR(BaseModel):
     @classmethod
     def build_model_from_args(cls, args):
         return cls(
-            args.hidden_size1, args.hidden_size2, args.noise, args.alpha, args.step, args.max_epoch, args.lr, args.cpu
+            args.hidden_size1, args.hidden_size2, args.noise, args.alpha, args.step, args.epochs, args.lr, args.cpu
         )
 
-    def __init__(self, hidden_size1, hidden_size2, noise, alpha, step, max_epoch, lr, cpu):
+    def __init__(self, hidden_size1, hidden_size2, noise, alpha, step, epochs, lr, cpu):
         super(DNGR, self).__init__()
         self.hidden_size1 = hidden_size1
         self.hidden_size2 = hidden_size2
         self.noise = noise
         self.alpha = alpha
         self.step = step
-        self.max_epoch = max_epoch
+        self.epochs = epochs
         self.lr = lr
+        self.cpu = cpu
 
     def scale_matrix(self, mat):
         mat = mat - np.diag(np.diag(mat))
@@ -123,7 +123,9 @@ class DNGR(BaseModel):
         emb_matrix = preprocessing.normalize(emb_matrix, "l2")
         return emb_matrix
 
-    def train(self, G):
+    def forward(self, graph, return_dict=False):
+        device = "cuda" if torch.cuda.is_available() and not self.cpu else "cpu"
+        G = graph.to_networkx()
         self.num_node = G.number_of_nodes()
         A = nx.adjacency_matrix(G).todense()
         PPMI = self.get_ppmi_matrix(A)
@@ -133,13 +135,13 @@ class DNGR(BaseModel):
         input_mat = torch.from_numpy(self.get_denoised_matrix(PPMI).astype(np.float32))
         model = DNGR_layer(self.num_node, self.hidden_size1, self.hidden_size2)
 
-        input_mat = input_mat.to(self.device)
-        model = model.to(self.device)
+        input_mat = input_mat.to(device)
+        model = model.to(device)
 
         opt = torch.optim.Adam(model.parameters(), lr=self.lr)
         loss_func = nn.MSELoss()
 
-        epoch_iter = tqdm(range(self.max_epoch))
+        epoch_iter = tqdm(range(self.epochs))
         for epoch in epoch_iter:
             opt.zero_grad()
             encoded, decoded = model.forward(input_mat)
@@ -147,5 +149,15 @@ class DNGR(BaseModel):
             Loss.backward()
             epoch_iter.set_description(f"Epoch: {epoch:03d},  Loss: {Loss:.8f}")
             opt.step()
-        embedding, _ = model.forward(input_mat)
-        return embedding.detach().cpu().numpy()
+        embeddings, _ = model.forward(input_mat)
+        embeddings = embeddings.detach().cpu().numpy()
+
+        if return_dict:
+            features_matrix = dict()
+            for vid, node in enumerate(G.nodes()):
+                features_matrix[node] = embeddings[vid]
+        else:
+            features_matrix = np.zeros((graph.num_nodes, embeddings.shape[1]))
+            nx_nodes = G.nodes()
+            features_matrix[nx_nodes] = embeddings[np.arange(graph.num_nodes)]
+        return features_matrix
