@@ -187,6 +187,12 @@ class Trainer(object):
             return best_model_w.model
 
         final_test = self.evaluate(best_model_w, dataset_w)
+
+        # clear the GPU memory
+        dataset = dataset_w.get_dataset()
+        if isinstance(dataset.data, Graph):
+            dataset.data.to("cpu")
+
         return final_test
 
     def evaluate(self, model_w: ModelWrapper, dataset_w: DataWrapper, cpu=False):
@@ -244,16 +250,16 @@ class Trainer(object):
         opt_wrap = model_w.setup_optimizer()
         if isinstance(opt_wrap, list) or isinstance(opt_wrap, tuple):
             assert len(opt_wrap) == 2
-            optimizers, lr_schedulars = opt_wrap
+            optimizers, lr_schedulers = opt_wrap
         else:
             optimizers = opt_wrap
-            lr_schedulars = None
+            lr_schedulers = None
 
         if not isinstance(optimizers, list):
             optimizers = [optimizers]
-        if lr_schedulars and not isinstance(lr_schedulars, list):
-            lr_schedulars = [lr_schedulars]
-        return optimizers, lr_schedulars
+        if lr_schedulers and not isinstance(lr_schedulers, list):
+            lr_schedulers = [lr_schedulers]
+        return optimizers, lr_schedulers
 
     def initialize(self, model_w, rank=0, master_addr: str = "localhost", master_port: int = 10008):
         if self.distributed_training:
@@ -269,12 +275,12 @@ class Trainer(object):
         else:
             return model_w.to(rank), None
 
-    def train(self, rank, model_w, dataset_w):
+    def train(self, rank, model_w, dataset_w):  # noqa: C901
         model_w, _ = self.initialize(model_w, rank=rank, master_addr=self.master_addr, master_port=self.master_port)
         self.data_controller.prepare_data_wrapper(dataset_w, rank)
         self.eval_data_back_to_cpu = dataset_w.data_back_to_cpu
 
-        optimizers, lr_schedulars = self.build_optimizer(model_w)
+        optimizers, lr_schedulers = self.build_optimizer(model_w)
         if optimizers[0] is None:
             return
 
@@ -300,10 +306,10 @@ class Trainer(object):
                 self.data_controller.training_proc_per_stage(dataset_w, rank)
 
             if self.progress_bar == "epoch":
-                epoch_iter = tqdm(range(self.epochs))
+                epoch_iter = tqdm(range(1, self.epochs + 1))
                 epoch_printer = Printer(epoch_iter.set_description, rank=rank, world_size=self.world_size)
             else:
-                epoch_iter = range(self.epochs)
+                epoch_iter = range(1, self.epochs + 1)
                 epoch_printer = Printer(print, rank=rank, world_size=self.world_size)
 
             self.logger.start()
@@ -315,7 +321,10 @@ class Trainer(object):
                 # inductive setting ..
                 dataset_w.train()
                 train_loader = dataset_w.on_train_wrapper()
-                training_loss = self.training_step(model_w, train_loader, optimizers, lr_schedulars, rank)
+                train_dataset = train_loader.get_dataset_from_loader()
+                if hasattr(train_dataset, "shuffle"):
+                    train_dataset.shuffle()
+                training_loss = self.train_step(model_w, train_loader, optimizers, lr_schedulers, rank)
 
                 print_str_dict["Epoch"] = epoch
                 print_str_dict["train_loss"] = training_loss
@@ -380,12 +389,13 @@ class Trainer(object):
         dataset_w.eval()
         if self.cpu_inference:
             model_w.to("cpu")
-            _device = device
+            _device = "cpu"
         else:
             _device = device
 
         val_loader = dataset_w.on_val_wrapper()
-        result = self.val_step(model_w, val_loader, _device)
+        with torch.no_grad():
+            result = self.val_step(model_w, val_loader, _device)
 
         model_w.to(device)
         return result
@@ -400,12 +410,16 @@ class Trainer(object):
         dataset_w.eval()
         if self.cpu_inference:
             model_w.to("cpu")
-            _device = device
+            _device = "cpu"
         else:
             _device = device
 
         test_loader = dataset_w.on_test_wrapper()
-        result = self.test_step(model_w, test_loader, _device)
+        if model_w.training_type == "unsupervised":
+            result = self.test_step(model_w, test_loader, _device)
+        else:
+            with torch.no_grad():
+                result = self.test_step(model_w, test_loader, _device)
 
         model_w.to(device)
         return result
@@ -419,7 +433,8 @@ class Trainer(object):
                 _device = "cpu"
             else:
                 _device = rank
-            result = fn(model_w, loader, _device)
+            with torch.no_grad():
+                result = fn(model_w, loader, _device)
             model_w.to(rank)
 
             object_list = [result]
@@ -428,7 +443,7 @@ class Trainer(object):
         dist.broadcast_object_list(object_list, src=0)
         return object_list[0]
 
-    def training_step(self, model_w, train_loader, optimizers, lr_schedulars, device):
+    def train_step(self, model_w, train_loader, optimizers, lr_schedulers, device):
         model_w.train()
         losses = []
 
@@ -437,6 +452,8 @@ class Trainer(object):
 
         for batch in train_loader:
             batch = move_to_device(batch, device)
+            if hasattr(batch, "train_mask") and batch.train_mask.sum().item() == 0:
+                continue
             loss = model_w.on_train_step(batch)
 
             for optimizer in optimizers:
@@ -449,12 +466,12 @@ class Trainer(object):
                 optimizer.step()
 
             losses.append(loss.item())
-        if lr_schedulars is not None:
-            for lr_schedular in lr_schedulars:
+        if lr_schedulers is not None:
+            for lr_schedular in lr_schedulers:
                 lr_schedular.step()
+
         return np.mean(losses)
 
-    @torch.no_grad()
     def val_step(self, model_w, val_loader, device):
         model_w.eval()
         if val_loader is None:
@@ -466,7 +483,6 @@ class Trainer(object):
                 move_to_device(batch, "cpu")
         return model_w.collect_notes()
 
-    # @torch.no_grad()
     def test_step(self, model_w, test_loader, device):
         model_w.eval()
         if test_loader is None:
